# ai-models-fourcastnet-gfs

>
> :warning: This plugin is now deprecated. Please use the newer version that can be found at https://github.com/jacob-radford/ai-models-gfs-fourcastnetv2
> 

`ai-models-fourcastnet-gfs` is an extension of the [ai-models-fourcastnet](https://github.com/ecmwf-lab/ai-models-fourcastnet) package, which itself is a plugin to run Nvidia's spherical harmonics tranformer with [ai-models](https://github.com/ecmwf-lab/ai-models).

FourCastNet: A Global Data-driven High-resolution Weather Model using Adaptive Fourier Neural Operators
https://arxiv.org/abs/2202.11214

The FourCastNet code was developed by the authors of the preprint: Jaideep Pathak, Shashank Subramanian, Peter Harrington, Sanjeev Raja, Ashesh Chattopadhyay, Morteza Mardani, Thorsten Kurth, David Hall, Zongyi Li, Kamyar Azizzadenesheli, Pedram Hassanzadeh, Karthik Kashinath, Animashree Anandkumar.

Version 0.1 of FourCastNet is used as default in ai-models.
https://portal.nersc.gov/project/m4134/FCN_weights_v0.1/

FourCastNet is released under **BSD 3-Clause License**, see [LICENSE_fourcastnet](LICENSE_fourcastnet) for more details.
